@@ -7,6 +7,7 @@ import numpy as np
 import pytest
 
 import pdal
+import pathlib
 
 DATADIRECTORY = os.path.join(os.path.dirname(__file__), "data")
 
@@ -34,7 +35,7 @@ def get_pipeline(filename):
 def test_dimensions():
     """Ask PDAL for its valid dimensions list"""
     dims = pdal.dimensions
-    assert 71 < len(dims) < 122
+    assert len(dims) > 0
 
 
 class TestPipeline:
@@ -487,6 +488,14 @@ class TestMesh:
         assert len(triangles) == 134
         assert triangles[0][0] == 29
 
+    def test_pathlib(self):
+        """Can we build a pipeline using pathlib.Path as the filenames"""
+        path = pathlib.Path("test/data/autzen-utm.las")
+        read = pdal.Reader(path)
+        pipeline = read.pipeline()
+        pipeline.execute()
+
+
 class TestDataFrame:
 
     @pytest.mark.skipif(
@@ -498,7 +507,8 @@ class TestDataFrame:
         p = r.pipeline()
         p.execute()
         df = p.get_dataframe(0)
-        assert df.size == 17040
+        assert len(df) == 1065
+        assert len(df.columns) == 20
 
     @pytest.mark.skipif(
         not pdal.pipeline.DataFrame,
